;; Generated package description from test-simple.el  -*- no-byte-compile: t -*-
(define-package "test-simple" "1.3.0.0.20170527.153219" "Simple Unit Test Framework for Emacs Lisp" '((cl-lib "0")) :keywords '("unit-test") :authors '(("Rocky Bernstein" . "rocky@gnu.org")) :maintainer '("Rocky Bernstein" . "rocky@gnu.org") :url "http://github.com/rocky/emacs-test-simple")
